@@ -15,7 +15,8 @@ class ClassificationAttribute:
     options: Optional[Iterable[ClassificationOption]] = None
 
     def __setattr__(self, name, value):
-        if (name == "classification_type" and value == ClassificationType.TEXT and self.__dict__.get("options")) or \
-                (name == "options" and value and self.__dict__.get("classification_type") == ClassificationType.TEXT):
+        if (name == "classification_type" and value == ClassificationType.TEXT and self.__dict__.get("options")) or (
+            name == "options" and value and self.__dict__.get("classification_type") == ClassificationType.TEXT
+        ):
             raise Exception("cannot assign options to a classification text")
         self.__dict__[name] = value
